@@ -277,7 +277,7 @@ static KeyCheckVal GE_check_known_key(const char* filename, key_ring_data* key)
    int fd;
    int found_name = 0;
    
-   g_snprintf(path, sizeof(path), "%s%s%s", gaim_home_dir(), G_DIR_SEPARATOR_S, filename);
+   g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
       
    gaim_debug(GAIM_DEBUG_INFO, "gaim-encryption", "Checking key file %s for name %s\n", path, key->name);
 
@@ -359,11 +359,13 @@ void GE_add_key_to_file(const char *filename, key_ring_data* key) {
    struct stat fdstat;
    
    gaim_debug(GAIM_DEBUG_INFO, "gaim-encryption", "Saving key to file:%s:%p\n", key->name, key->account);
-   g_snprintf(path, sizeof(path), "%s%s%s", gaim_home_dir(), G_DIR_SEPARATOR_S, filename);
+   g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
 
    fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
    if (fd == -1) {
       gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Error opening key file %s for write\n", path);
+      /* WIN32 doesn't have user-based file permissions, so skips this */
+#ifdef S_IRWXG
       if (chmod(path, S_IRUSR | S_IWUSR) == -1) {
 
          gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Unable to change file mode, aborting\n");
@@ -372,6 +374,7 @@ void GE_add_key_to_file(const char *filename, key_ring_data* key) {
          GE_ui_error(errbuf);
          return;
       }
+#endif
       fd = open(path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
       if (fd == -1) {
          gaim_debug(GAIM_DEBUG_ERROR, "gaim-encryption", "Changed mode, but still wonky.  Aborting.\n");
@@ -449,7 +452,7 @@ void GE_del_one_key_from_file(const char *filename, int key_num, const char *nam
    GE_escape_name(normalized_start);
    g_string_append_printf(normalized_start, " ");
 
-   g_snprintf(path, sizeof(path), "%s%s%s", gaim_home_dir(), G_DIR_SEPARATOR_S, filename);
+   g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
    
    /* Look for name in the file.  If it's not there, we're done */
    fp = fopen(path, "r");
@@ -551,7 +554,7 @@ void GE_del_key_from_file(const char *filename, const char *name, GaimAccount *a
    GE_escape_name(normalized_start);
    g_string_append_printf(normalized_start, " ");
 
-   g_snprintf(path, sizeof(path), "%s%s%s", gaim_home_dir(), G_DIR_SEPARATOR_S, filename);
+   g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
    
    /* Look for name in the file.  If it's not there, we're done */
    fp = fopen(path, "r");
@@ -633,7 +636,7 @@ key_ring * GE_load_keys(const char *filename) {
    GaimAccount* account;
 
 
-   g_snprintf(path, sizeof(path), "%s%s%s", gaim_home_dir(), G_DIR_SEPARATOR_S, filename);
+   g_snprintf(path, sizeof(path), "%s%s%s", gaim_user_dir(), G_DIR_SEPARATOR_S, filename);
    if( (fp = fopen(path, "r")) != NULL ) {
       do {
       	 /* 7999 = MAX_KEY_STORLEN - 1 */
